# Objective

write a rust library that will be made available in python. this is a sample test project to better understand the steps to create the rust library is available to python program and can be installed by using pip install or other package manager like poetry, uv and etc.

# approach
start simple with linear algebra crate that performs basic linear algebra and matrix multiplication and make that function available in the python. 
